pub struct Args {Show 40 fields
signing_key: Option<PathBuf>,
pub signing_share: Option<PathBuf>,
pub listen_address: SocketAddr,
pub metrics_address: SocketAddr,
pub max_message_size_bytes: u32,
pub worker_threads: usize,
pub message_backlog: usize,
pub mailbox_size: usize,
pub deque_size: usize,
pub fee_recipient: Option<Address>,
pub wait_for_peer_response: PositiveDuration,
pub wait_for_notarizations: PositiveDuration,
pub wait_for_proposal: PositiveDuration,
pub wait_to_rebroadcast_nullify: PositiveDuration,
pub views_to_track: u64,
pub inactive_views_until_leader_skip: u64,
pub time_to_prepare_proposal_transactions: PositiveDuration,
pub minimum_time_before_propose: PositiveDuration,
pub enable_subblocks: bool,
pub time_to_build_subblock: PositiveDuration,
pub use_local_defaults: bool,
pub bypass_ip_check: bool,
pub allow_private_ips: bool,
pub allow_dns: bool,
pub synchrony_bound: PositiveDuration,
pub wait_before_peers_redial: PositiveDuration,
pub wait_before_peers_reping: PositiveDuration,
pub wait_before_peers_discovery: PositiveDuration,
pub connection_per_peer_min_period: PositiveDuration,
pub handshake_per_ip_min_period: PositiveDuration,
pub handshake_per_subnet_min_period: PositiveDuration,
pub handshake_stale_after: PositiveDuration,
pub handshake_timeout: PositiveDuration,
pub max_concurrent_handshakes: NonZeroU32,
pub time_to_unblock_byzantine_peer: PositiveDuration,
pub backfill_frequency: NonZeroU32,
pub subblock_broadcast_interval: PositiveDuration,
pub fcu_heartbeat_interval: PositiveDuration,
loaded_signing_key: OnceLock<Option<SigningKey>>,
pub storage_dir: Option<PathBuf>,
}Expand description
Command line arguments for configuring the consensus layer of a tempo node.
Fields
signing_key: Option<PathBuf>The file containing the ed25519 signing key for p2p communication.
The file containing a share of the bls12-381 threshold signing key.
listen_address: SocketAddrThe socket address that will be bound to listen for consensus communication from other nodes.
metrics_address: SocketAddrThe socket address that will be bound to export consensus specific metrics.
max_message_size_bytes: u32worker_threads: usizeThe number of worker threads assigned to consensus.
message_backlog: usizeThe maximum number of messages that can be queued on the various consensus channels before blocking.
mailbox_size: usizeThe overall number of items that can be received on the various consensus channels before blocking.
deque_size: usizeThe maximum number of blocks that will be buffered per peer. Used to send and receive blocks over the network of the consensus layer.
fee_recipient: Option<Address>The fee recipient that will be specified by this node. Will use the coinbase address in genesis if not set.
wait_for_peer_response: PositiveDurationThe amount of time to wait for a peer to respond to a consensus request.
wait_for_notarizations: PositiveDurationThe amount of time to wait for a quorum of notarizations in a view before attempting to skip the view.
wait_for_proposal: PositiveDurationAmount of time to wait to receive a proposal from the leader of the current view.
wait_to_rebroadcast_nullify: PositiveDurationThe amount of time to wait before retrying a nullify broadcast if stuck in a view.
views_to_track: u64The number of views (like voting rounds) to track. Also called an activity timeout.
inactive_views_until_leader_skip: u64The number of views (voting rounds) a validator is allowed to be inactive until it is immediately skipped should leader selection pick it as a proposer. Also called a skip timeout.
time_to_prepare_proposal_transactions: PositiveDurationThe maximum amount of time to spend on executing transactions when preparing a proposal as a leader.
NOTE: This only limits the time the builder spends on transaction execution, and does not
include the state root calculation time. For this reason, we keep it well below consensus.time-to-build-proposal.
minimum_time_before_propose: PositiveDurationThe minimum amount of time this node waits before sending a proposal
The intention is to keep block times stable even if there is low load on the network.
This value should be well below consensus.wait-for-proposal to account
for the leader to enter the view, build and broadcast the proposal, and
have the other peers receive the proposal.
enable_subblocks: boolWhether to enable subblock processing.
When disabled, the node will not build or broadcast subblocks, and will ignore any incoming subblocks from the network.
time_to_build_subblock: PositiveDurationThe amount of time this node will use to construct a subblock before
sending it to the next proposer. This value should be well below
consensus.time-to-build-proposal to ensure the subblock is received
before the build is complete.
use_local_defaults: boolUse defaults optimized for local network environments. Only enable in non-production network nodes.
bypass_ip_check: boolReduces security by disabling IP-based connection filtering. Connections are still authenticated via public key cryptography, but anyone can attempt handshakes, increasing exposure to DoS attacks. Only enable in trusted network environments.
allow_private_ips: boolWhether to allow connections with private IP addresses.
allow_dns: boolWhether to allow DNS-based ingress addresses.
synchrony_bound: PositiveDurationTime into the future that a timestamp can be and still be considered valid.
wait_before_peers_redial: PositiveDurationHow long to wait before attempting to dial peers. Run across all peers including the newly discovered ones.
wait_before_peers_reping: PositiveDurationHow long to wait before sending a ping message to peers for liveness detection.
wait_before_peers_discovery: PositiveDurationHow often to query for new dialable peers.
connection_per_peer_min_period: PositiveDurationMinimum time between connection attempts to the same peer. A rate-limit on connection attempts.
handshake_per_ip_min_period: PositiveDurationMinimum time between handshake attempts from a single IP address. A rate-limit on attempts.
handshake_per_subnet_min_period: PositiveDurationMinimum time between handshake attempts from a single subnet. A rate-limit on attempts.
handshake_stale_after: PositiveDurationDuration after which a handshake message is considered stale.
handshake_timeout: PositiveDurationTimeout for the handshake process.
max_concurrent_handshakes: NonZeroU32Maximum number of concurrent handshake attempts allowed.
time_to_unblock_byzantine_peer: PositiveDurationDuration after which a blocked peer is allowed to reconnect.
backfill_frequency: NonZeroU32Rate limit when backfilling blocks (requests per second).
subblock_broadcast_interval: PositiveDurationThe interval at which to broadcast subblocks to the next proposer.
Each built subblock is immediately broadcasted to the next proposer (if it’s known).
We broadcast subblock every subblock-broadcast-interval to ensure the next
proposer is aware of the subblock even if they were slightly behind the chain
once we sent it in the first time.
fcu_heartbeat_interval: PositiveDurationThe interval at which to send a forkchoice update heartbeat to the execution layer. This is sent periodically even when there are no new blocks to ensure the execution layer stays in sync with the consensus layer’s view of the chain head.
loaded_signing_key: OnceLock<Option<SigningKey>>Cache for the signing key loaded from CLI-provided file.
storage_dir: Option<PathBuf>Where to store consensus data. If not set, this will be derived from
--datadir.
Implementations
Sourceimpl Args
impl Args
Sourcepub(crate) fn signing_key(&self) -> Result<Option<SigningKey>>
pub(crate) fn signing_key(&self) -> Result<Option<SigningKey>>
Returns the signing key loaded from specified file.
Sourcepub fn public_key(&self) -> Result<Option<PublicKey>>
pub fn public_key(&self) -> Result<Option<PublicKey>>
Returns the public key derived from the configured signing key, if any.